; ------------------------------------------------------------------------------------------------
; GMCTST v0.1	Pere Serrat 2019-02-25
; Setup Sound and send data for a single note to channel 0, wait for Key and stop
; ------------------------------------------------------------------------------------------------
MPICFG	equ	$ff7f							; MPI config byte
HOOKSINI	equ	$015e							; system Hooks beginning
HOOKSEND	equ	$01a9							; system Hooks end
DRVSLOT	equ	$ff							; slot 4 
GMCSLOT	equ	$00							; slot 1
; ------------------------------------------------------------------------------------------------
			org	$4000
			put	$4000
; ------------------------------------------------------------------------------------------------
			orcc	#$50							; disable interrupts
												; save curent hooks values
			ldx	#HOOKSINI					; point to 1st system hook
			ldu	#copHooks					; point to buffer area
			ldb	#$39							; get a RTS opcode
L01		lda	,x								; get 1st byte of a hook
			sta	,u+							; put into buffer
			stb	,x								; substitute by a RTS
			leax	3,x							; point to next hook
			cmpx	#HOOKSEND					; already done?
			blo	L01							; no, loop
; ------------------------------------------------------------------------------------------------
			lda	#GMCSLOT						; get GMC slot number		
			sta	MPICFG						; set MPI to it
; ------------------------------------------------------------------------------------------------
												; configure sound source 
			lda	$ff01							; access PIA0 side A control register
			anda	#%11110111					; reset bit 3 (SEL 1)
			sta	$ff01							; update value
			lda	$ff03							; access PIA0 side B control register
			ora	#%00001000					; set bit 3 (SEL 2) - 10 = cartridge sound
			sta	$ff03							; update value
			lda	$ff23							; access PIA1 side B control register
			ora	#%00001000					; set bit 3 (6 bit sound enable)
			sta	$ff23							; update value
; ------------------------------------------------------------------------------------------------
												; set max attenuation to all channels (volume 0)
			ldx	#$ff41						; GMC register
			lda	#%10011111					; 159d = $9f
			sta	,x								; send max attenuation for channel 0
			lda	#%10111111					; 191d = $bf
			sta	,x								; send max attenuation for channel 1
			lda	#%11011111					; 223d = $df
			sta	,x								; send max attenuation for channel 2
			lda	#%11111111					; 255d = $ff
			sta	,x								; send max attenuation for channel 3
; ------------------------------------------------------------------------------------------------
												; send data for a single note to channel 0
			lda	#%10001110					; 142d = $8e - Latch Byte
			sta	,x								; set frequency (low 4 bits) in channel 0
			lda	#%00111000					; 56d = $38 - Data Byte
			sta	,x								; set frequency (high 6 bits) in channel 0
			lda	#%10010001					; 145d = $91 - Latch Byte
			sta	,x								; set attenuation in channel 0
wfK1		jsr	[$A000]						; read key			
			beq	wfK1							; none? loopback
			lda	#%10011111					; 159d = $9f - Latch Byte
			sta	,x								; silence: set max attenuation in channel 0
; ------------------------------------------------------------------------------------------------
RstHooks	ldx	#HOOKSINI					; point to 1st system hook
			ldu	#copHooks					; point to buffer area
L02		lda	,u+							; gte a byte from buffer
			sta	,x								; put as 1st byte of hook
			leax	3,x							; point to next hook
			cmpx	#HOOKSEND					; already done?
			blo	L02							; no, loop
			lda	#DRVSLOT						; drives slot
			sta	MPICFG						; set MPI to it
			andcc	#$af							; enable interrupts	
			rts									; return
; ------------------------------------------------------------------------------------------------
copHooks	rzb	26								; buffer for 1st byte of hooks
; ------------------------------------------------------------------------------------------------
EndPgm 	equ	*
